==> kubernetes-model-gatewayapi-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GRPCRouteMatchFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GRPCRouteMatchFluent<A extends GRPCRouteMatchFluent<A>> extends Fluent<A>{
  public A addToHeaders(Integer index,GRPCHeaderMatch item);
  public A setToHeaders(Integer index,GRPCHeaderMatch item);
  public A addToHeaders(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCHeaderMatch... items);
  public A addAllToHeaders(Collection<GRPCHeaderMatch> items);
  public A removeFromHeaders(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCHeaderMatch... items);
  public A removeAllFromHeaders(Collection<GRPCHeaderMatch> items);
  public A removeMatchingFromHeaders(Predicate<GRPCHeaderMatchBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHeaders instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GRPCHeaderMatch> getHeaders();
  public List<GRPCHeaderMatch> buildHeaders();
  public GRPCHeaderMatch buildHeader(Integer index);
  public GRPCHeaderMatch buildFirstHeader();
  public GRPCHeaderMatch buildLastHeader();
  public GRPCHeaderMatch buildMatchingHeader(Predicate<GRPCHeaderMatchBuilder> predicate);
  public Boolean hasMatchingHeader(Predicate<GRPCHeaderMatchBuilder> predicate);
  public A withHeaders(List<GRPCHeaderMatch> headers);
  public A withHeaders(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCHeaderMatch... headers);
  public Boolean hasHeaders();
  public A addNewHeader(String name,String type,String value);
  public GRPCRouteMatchFluent.HeadersNested<A> addNewHeader();
  public GRPCRouteMatchFluent.HeadersNested<A> addNewHeaderLike(GRPCHeaderMatch item);
  public GRPCRouteMatchFluent.HeadersNested<A> setNewHeaderLike(Integer index,GRPCHeaderMatch item);
  public GRPCRouteMatchFluent.HeadersNested<A> editHeader(Integer index);
  public GRPCRouteMatchFluent.HeadersNested<A> editFirstHeader();
  public GRPCRouteMatchFluent.HeadersNested<A> editLastHeader();
  public GRPCRouteMatchFluent.HeadersNested<A> editMatchingHeader(Predicate<GRPCHeaderMatchBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMethod instead.
   * @return The buildable object.
   */
  @Deprecated
  public GRPCMethodMatch getMethod();
  public GRPCMethodMatch buildMethod();
  public A withMethod(GRPCMethodMatch method);
  public Boolean hasMethod();
  public A withNewMethod(String method,String service,String type);
  public GRPCRouteMatchFluent.MethodNested<A> withNewMethod();
  public GRPCRouteMatchFluent.MethodNested<A> withNewMethodLike(GRPCMethodMatch item);
  public GRPCRouteMatchFluent.MethodNested<A> editMethod();
  public GRPCRouteMatchFluent.MethodNested<A> editOrNewMethod();
  public GRPCRouteMatchFluent.MethodNested<A> editOrNewMethodLike(GRPCMethodMatch item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface HeadersNested<N> extends Nested<N>,GRPCHeaderMatchFluent<GRPCRouteMatchFluent.HeadersNested<N>>{
    public N and();
    public N endHeader();
    
  }
  public interface MethodNested<N> extends Nested<N>,GRPCMethodMatchFluent<GRPCRouteMatchFluent.MethodNested<N>>{
    public N and();
    public N endMethod();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GRPCRouteMatchFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface GRPCRouteMatchFluent<A extends GRPCRouteMatchFluent<A>> extends Fluent<A>{
  public A addToHeaders(int index,GRPCHeaderMatch item);
  public A setToHeaders(int index,GRPCHeaderMatch item);
  public A addToHeaders(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCHeaderMatch... items);
  public A addAllToHeaders(Collection<GRPCHeaderMatch> items);
  public A removeFromHeaders(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCHeaderMatch... items);
  public A removeAllFromHeaders(Collection<GRPCHeaderMatch> items);
  public A removeMatchingFromHeaders(Predicate<GRPCHeaderMatchBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHeaders instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GRPCHeaderMatch> getHeaders();
  public List<GRPCHeaderMatch> buildHeaders();
  public GRPCHeaderMatch buildHeader(int index);
  public GRPCHeaderMatch buildFirstHeader();
  public GRPCHeaderMatch buildLastHeader();
  public GRPCHeaderMatch buildMatchingHeader(Predicate<GRPCHeaderMatchBuilder> predicate);
  public Boolean hasMatchingHeader(Predicate<GRPCHeaderMatchBuilder> predicate);
  public A withHeaders(List<GRPCHeaderMatch> headers);
  public A withHeaders(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCHeaderMatch... headers);
  public Boolean hasHeaders();
  public A addNewHeader(String name,String type,String value);
  public GRPCRouteMatchFluent.HeadersNested<A> addNewHeader();
  public GRPCRouteMatchFluent.HeadersNested<A> addNewHeaderLike(GRPCHeaderMatch item);
  public GRPCRouteMatchFluent.HeadersNested<A> setNewHeaderLike(int index,GRPCHeaderMatch item);
  public GRPCRouteMatchFluent.HeadersNested<A> editHeader(int index);
  public GRPCRouteMatchFluent.HeadersNested<A> editFirstHeader();
  public GRPCRouteMatchFluent.HeadersNested<A> editLastHeader();
  public GRPCRouteMatchFluent.HeadersNested<A> editMatchingHeader(Predicate<GRPCHeaderMatchBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMethod instead.
   * @return The buildable object.
   */
  @Deprecated
  public GRPCMethodMatch getMethod();
  public GRPCMethodMatch buildMethod();
  public A withMethod(GRPCMethodMatch method);
  public Boolean hasMethod();
  public A withNewMethod(String method,String service,String type);
  public GRPCRouteMatchFluent.MethodNested<A> withNewMethod();
  public GRPCRouteMatchFluent.MethodNested<A> withNewMethodLike(GRPCMethodMatch item);
  public GRPCRouteMatchFluent.MethodNested<A> editMethod();
  public GRPCRouteMatchFluent.MethodNested<A> editOrNewMethod();
  public GRPCRouteMatchFluent.MethodNested<A> editOrNewMethodLike(GRPCMethodMatch item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface HeadersNested<N> extends Nested<N>,GRPCHeaderMatchFluent<GRPCRouteMatchFluent.HeadersNested<N>>{
    public N and();
    public N endHeader();
    
  }
  public interface MethodNested<N> extends Nested<N>,GRPCMethodMatchFluent<GRPCRouteMatchFluent.MethodNested<N>>{
    public N and();
    public N endMethod();
    
  }
  
}
